pub enum CacheEvent {
AtomicAdd(String, i32),
KeyDelete(String),
ScalarSet(String, String),
ListClear(String),
ListPush(String, String),
ListRemoveItem(String, String),
SetAdd(String, String),
SetRemoveItem(String, String),
}Expand description
Indicates an event that has occurred on a distributed cache. In all of the variants of this event, the first parameter is always the key
Variants
AtomicAdd(String, i32)
KeyDelete(String)
ScalarSet(String, String)
ListClear(String)
ListPush(String, String)
ListRemoveItem(String, String)
SetAdd(String, String)
SetRemoveItem(String, String)